"""
EssentiaX AI Module - Advanced AI-Powered Insights
"""

from .advanced_insights import (
    AdvancedInsightsEngine, 
    assess_data_quality, 
    generate_recommendations,
    interpret_statistical_results
)

__all__ = [
    'AdvancedInsightsEngine',
    'assess_data_quality',
    'generate_recommendations',
    'interpret_statistical_results'
]